Changes
~~~~~~~

Future (?)
----------
- pytest tools for BDD

0.5.1 (2018-12-04)
--------------------
- First PyPI release
- Module change detection fixes
- Testing db teardown (close leaked db conections)

0.5.0 (2018-11-04)
--------------------
- Start of project
